@@ -104,24 +104,14 @@ class Servico:
         if self.forcar_execucao():
             return True
         hoje, json = datetime.now(), response.json()[0]
-        json['fe'] = json.pop('fim_execucao')
-        fim_execucao = {19: f'{json.get("fe")}.0'}.get(len(json.get('fe')), json.get('fe'))
-        no_horario = hoje.time() >= datetime.strptime(
-            json.get('hora_agendamento', '01:00:00'), '%H:%M:%S',
-        ).time()
+        fim_execucao = {19: f'{json["fim_execucao"]}.0'}.get(len(str(json['fim_execucao'])), json['fim_execucao'])
+        no_horario = hoje.time() >= datetime.strptime(json.get('hora_agendamento', '01:00:00'), '%H:%M:%S').time()
         executou_hoje = all([
             json.get('status') == 'S',
             fim_execucao,
-            self.format_datetime(fim_execucao).date() == hoje.date(),
+            datetime.strptime(fim_execucao, '%Y-%m-%dT%H:%M:%S.%f').date() == hoje.date(),
         ])
-        return all(
-            [
-                self.ativo(),
-                not self.executado(),
-                no_horario,
-                not executou_hoje,
-            ]
-        )
+        return all([self.ativo(), not self.executado(), no_horario, not executou_hoje])
 
         def limpar_controle(self):
             return Controle.limpar({'_id_servico': self.id})
